@@ -1,10 +1,11 @@
 package Lemonldap::NG::Common::Conf::CDBI;
 
 use strict;
-require Storable;
+use utf8;
+use JSON;
 use Lemonldap::NG::Common::Conf::_DBI;
 
-our $VERSION = '1.4.0';
+our $VERSION = '1.9.1';
 our @ISA     = qw(Lemonldap::NG::Common::Conf::_DBI);
 
 sub store {
@@ -13,7 +14,7 @@ sub store {
     my $req;
     my $lastCfg = $self->lastCfg;
 
-    $fields = Storable::nfreeze($fields);
+    $fields = to_json($fields);
 
     if ( $lastCfg == $cfgNum ) {
         $req = $self->_dbh->prepare(
@@ -31,7 +32,6 @@ sub store {
         $self->logError;
         return UNKNOWN_ERROR;
     }
-    eval { $self->_dbh->do("COMMIT"); };
     return $cfgNum;
 }
 
@@ -46,7 +46,13 @@ sub load {
         return 0;
     }
     my $r;
-    eval { $r = Storable::thaw( $row->[0] ); };
+    if ( $row->[0] =~ /^\s*\{/s ) {
+        eval { $r = from_json( $row->[0] ); };
+    }
+    else {    # Old format
+        require Storable;
+        eval { $r = Storable::thaw( $row->[0] ); };
+    }
     if ($@) {
         $Lemonldap::NG::Common::Conf::msg .=
           "Bad stored data in conf database: $@ \n";
