@@ -1,10 +1,11 @@
 package Lemonldap::NG::Common::Conf::_DBI;
 
 use strict;
+use utf8;
 use DBI;
 use Lemonldap::NG::Common::Conf::Constants;    #inherits
 
-our $VERSION = '1.4.0';
+our $VERSION = '1.9.1';
 our @ISA     = qw(Lemonldap::NG::Common::Conf::Constants);
 our ( @EXPORT, %EXPORT_TAGS );
 
@@ -23,7 +24,8 @@ sub prereq {
           '"dbiChain" is required in *DBI configuration type';
         return 0;
     }
-    print STDERR __PACKAGE__ . 'Warning: "dbiUser" parameter is not set'
+    $Lemonldap::NG::Common::Conf::msg .=
+      'Warning: "dbiUser" parameter is not set'
       unless ( $self->{dbiUser} );
     $self->{dbiTable} ||= "lmConfig";
     1;
@@ -87,8 +89,13 @@ sub unlock {
 
 sub delete {
     my ( $self, $cfgNum ) = @_;
-    $self->_dbh->do( "DELETE from " . $self->{dbiTable} . " WHERE cfgNum=?",
-        {}, $cfgNum );
+    my $req =
+      $self->_dbh->prepare("DELETE FROM $self->{dbiTable} WHERE cfgNum=?");
+    my $res = $req->execute($cfgNum);
+    $Lemonldap::NG::Common::Conf::msg .=
+      "Unable to find conf $cfgNum (" . $self->_dbh->errstr . ")"
+      unless ($res);
+    return $res;
 }
 
 sub logError {
