@@ -7,7 +7,6 @@ package Lemonldap::NG::Common::Notification;
 
 use strict;
 use utf8;
-use Lemonldap::NG::Portal::SharedConf;
 use XML::LibXML;
 use XML::LibXSLT;
 use CGI::Cookie;
@@ -16,7 +15,7 @@ use Scalar::Util 'weaken';
 #inherits Lemonldap::NG::Common::Notification::DBI
 #inherits Lemonldap::NG::Common::Notification::File
 
-our $VERSION = '1.4.0';
+our $VERSION = '1.9.1';
 our ( $msg, $parser );
 
 ## @cmethod Lemonldap::NG::Common::Notification new(hashref storage)
@@ -24,7 +23,7 @@ our ( $msg, $parser );
 # @param $storage same syntax as Lemonldap::NG::Common::Conf object
 # @return Lemonldap::NG::Common::Notification object
 sub new {
-    my ( $class, $storage ) = splice @_;
+    my ( $class, $storage ) = @_;
     my $self = bless {}, $class;
     (%$self) = (%$storage);
     unless ( $self->{p} ) {
@@ -55,7 +54,7 @@ sub new {
 # @param $mess Text to log
 # @param $level Level (debug|info|notice|error)
 sub lmLog {
-    my ( $self, $mess, $level ) = splice @_;
+    my ( $self, $mess, $level ) = @_;
     $self->{p}->lmLog( "[Notification] $mess", $level );
 }
 
@@ -65,7 +64,7 @@ sub lmLog {
 # @param $portal Lemonldap::NG::Portal object that call
 # @return HTML fragment containing form content
 sub getNotification {
-    my ( $self, $portal ) = splice @_;
+    my ( $self, $portal ) = @_;
     my ( @files, $form );
 
     # Get user datas,
@@ -197,7 +196,7 @@ sub getNotification {
 # @param $portal Lemonldap::NG::Portal object that call
 # @return true if all checkboxes have been checked
 sub checkNotification {
-    my ( $self, $portal ) = splice @_, 0, 2;
+    my ( $self, $portal ) = ( @_, 0, 2 );
     my ( $refs, $checks );
 
     # First, rebuild environment (cookies,...)
@@ -341,7 +340,7 @@ sub checkNotification {
 # @param $xml XML string containing notification
 # @return number of notifications done
 sub newNotification {
-    my ( $self, $xml ) = splice @_;
+    my ( $self, $xml ) = @_;
     eval { $xml = $parser->parse_string($xml); };
     if ($@) {
         $self->lmLog( "Unable to read XML file : $@", 'error' );
@@ -395,7 +394,7 @@ sub newNotification {
 ## @param $myref notification's reference
 ## @return number of deleted notifications
 sub deleteNotification {
-    my ( $self, $uid, $myref ) = splice @_;
+    my ( $self, $uid, $myref ) = @_;
     my @data;
 
     # Check input parameters
@@ -520,6 +519,17 @@ sub _newNotif {
     return &{ $_[0]->{type} . '::newNotif' }(@_);
 }
 
+## @method private string _getIdentifier(string uid, string ref, string date)
+# Get notification identifier
+# @param $uid uid
+# @param $ref ref
+# @param $date date
+# @return the notification identifier
+sub _getIdentifier {
+    no strict 'refs';
+    return &{ $_[0]->{type} . '::getIdentifier' }(@_);
+}
+
 1;
 
 __END__
@@ -568,11 +578,11 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =over
 
-=item Copyright (C) 2009, 2010, 2011, 2012 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+=item Copyright (C) 2009-2016 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 
 =item Copyright (C) 2012 by Sandro Cazzaniga, E<lt>cazzaniga.sandro@gmail.comE<gt>
 
-=item Copyright (C) 2010, 2011, 2012 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+=item Copyright (C) 2010-2012 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
 
 =back
 
