@@ -13,7 +13,7 @@
 
 package Lemonldap::NG::Manager::Build::Tree;
 
-our $VERSION = '1.9.3';
+our $VERSION = '1.9.6';
 
 # TODO: Missing:
 #  * activeTimer
@@ -481,6 +481,7 @@ sub tree {
                         'storePassword',
                         'timeout',
                         'timeoutActivity',
+                        'timeoutActivityInterval',
                         'grantSessionRules',
                         {
                             title => 'sessionStorage',
@@ -604,7 +605,8 @@ sub tree {
                                 'key',
                                 'trustedDomains',
                                 'useSafeJail',
-                                'checkXSS'
+                                'checkXSS',
+                                'lwpSslOpts'
                             ]
                         },
                         {
@@ -661,8 +663,16 @@ sub tree {
                                 }
                             ]
                         },
+                        'nginxCustomHandlers',
                         'logoutServices',
-                        'multiValuesSeparator'
+                        'multiValuesSeparator',
+                        {
+                            title => 'forms',
+                            nodes => [
+                                'infoFormMethod',     'confirmFormMethod',
+                                'redirectFormMethod', 'activeTimer',
+                            ]
+                        }
                     ]
                 }
             ]
