@@ -13,7 +13,7 @@ use Lemonldap::NG::Portal::_Browser;
 use Cache::FileCache;
 
 our @ISA     = (qw(Lemonldap::NG::Portal::_Browser));
-our $VERSION = '1.4.0';
+our $VERSION = '1.9.6';
 our $initDone;
 
 BEGIN {
@@ -109,7 +109,7 @@ sub extractFormInfo {
     # 3. Check if an OpenID url has been submitted
     else {
         my $tmp = $url;
-        $tmp =~ m#^http//(.*?)/#;
+        $tmp =~ m#^https?://(.*?)/#;
         if ( $tmp =~
             $self->{_reopenIdIDPList} xor $self->{_openIdIDPListIsWhite} )
         {
@@ -291,7 +291,7 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =item Copyright (C) 2010 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 
-=item Copyright (C) 2010, 2012 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+=item Copyright (C) 2010-2012 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
 
 =back
 
