@@ -11,7 +11,7 @@ use Lemonldap::NG::Portal::Simple;
 use Lemonldap::NG::Portal::_SAML;    #inherits
 use Lemonldap::NG::Common::Conf::SAML::Metadata;
 
-our $VERSION = '1.4.2';
+our $VERSION = '1.9.6';
 our @ISA     = qw(Lemonldap::NG::Portal::_SAML);
 
 ## @apmethod int authInit()
@@ -192,15 +192,17 @@ sub extractFormInfo {
             }
 
             # Do we check conditions?
-            my $checkConditions =
+            my $checkTime =
               $self->{samlIDPMetaDataOptions}->{$idpConfKey}
-              ->{samlIDPMetaDataOptionsCheckConditions};
+              ->{samlIDPMetaDataOptionsCheckTime};
+            my $checkAudience =
+              $self->{samlIDPMetaDataOptions}->{$idpConfKey}
+              ->{samlIDPMetaDataOptionsCheckAudience};
 
-            # Check conditions - time and audience
-            if (
-                $checkConditions
-                and !$self->validateConditions(
-                    $assertion, $self->getMetaDataURL( "samlEntityID", 0, 1 )
+            unless (
+                $self->validateConditions(
+                    $assertion, $self->getMetaDataURL( "samlEntityID", 0, 1 ),
+                    $checkTime, $checkAudience
                 )
               )
             {
@@ -208,8 +210,12 @@ sub extractFormInfo {
                 return PE_SAML_CONDITIONS_ERROR;
             }
 
+            my $relayStateURL =
+              $self->{samlIDPMetaDataOptions}->{$idpConfKey}
+              ->{samlIDPMetaDataOptionsRelayStateURL};
+
             #  Extract RelayState information
-            if ( $self->extractRelayState($relaystate) ) {
+            if ( $self->extractRelayState( $relaystate, $relayStateURL ) ) {
                 $self->lmLog( "RelayState $relaystate extracted", 'debug' );
             }
 
@@ -801,7 +807,8 @@ sub extractFormInfo {
                 name => $self->{_idpList}->{$_}->{name}
               };
         }
-        $self->{list} = \@list;
+        $self->{list}            = \@list;
+        $self->{confirmRemember} = 1;
 
         # Delete existing IDP resolution cookie
         push @{ $self->{cookie} },
@@ -905,7 +912,7 @@ sub extractFormInfo {
     my $method =
       $self->{samlIDPMetaDataOptions}->{$idpConfKey}
       ->{samlIDPMetaDataOptionsSSOBinding};
-    $method = $self->getHttpMethod($method) if $method;
+    $method = $self->getHttpMethod($method);
 
     # If no method defined, get first HTTP method
     unless ( defined $method ) {
@@ -1130,7 +1137,18 @@ sub setAuthSessionInfo {
     # Dump Lasso objects in session
     $self->{sessionInfo}->{_lassoSessionDump}  = $session->dump()  if $session;
     $self->{sessionInfo}->{_lassoIdentityDump} = $identity->dump() if $identity;
-    $self->{sessionInfo}->{_samlToken} = $self->{_samlToken};
+
+    # Keep SAML Token in session
+    my $store_samlToken =
+      $self->{samlIDPMetaDataOptions}->{$idpConfKey}
+      ->{samlIDPMetaDataOptionsStoreSAMLToken};
+    if ($store_samlToken) {
+        $self->lmLog( "Store SAML Token in session", 'debug' );
+        $self->{sessionInfo}->{_samlToken} = $self->{_samlToken};
+    }
+    else {
+        $self->lmLog( "SAML Token will not be stored in session", 'debug' );
+    }
 
     $self->{_lassoLogin} = $login;
 
@@ -1276,7 +1294,7 @@ sub authLogout {
     $method =
       $self->{samlIDPMetaDataOptions}->{$idpConfKey}
       ->{samlIDPMetaDataOptionsSLOBinding};
-    $method = $self->getHttpMethod($method) if $method;
+    $method = $self->getHttpMethod($method);
 
     # If no method defined, get first HTTP method
     unless ( defined $method ) {
@@ -1284,11 +1302,11 @@ sub authLogout {
         $method = $self->getFirstHttpMethod( $server, $idp, $protocolType );
     }
 
-    # Failback to SOAP
+    # Skip SLO if no method found
     unless ( defined $method and $method != -1 ) {
         $self->lmLog( "No method found with IDP $idpConfKey for SLO profile",
             'debug' );
-        $method = $self->getHttpMethod("soap");
+        return PE_OK;
     }
 
     $self->lmLog(
@@ -1434,9 +1452,16 @@ sub authForce {
 }
 
 ## @apmethod boolean authFinish()
-# Associate NameID and SessionIndex to a local session
+# Do nothing
 # @return Lemonldap::NG::Portal error code
 sub authFinish {
+    PE_OK;
+}
+
+## @apmethod boolean authPostStore()
+# Associate NameID and SessionIndex to a local session
+# @return Lemonldap::NG::Portal error code
+sub authPostStore {
     my $self = shift;
     my %h;
 
@@ -1534,13 +1559,13 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =over
 
-=item Copyright (C) 2009, 2010 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+=item Copyright (C) 2009-2010 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 
 =item Copyright (C) 2012 by Sandro Cazzaniga, E<lt>cazzaniga.sandro@gmail.comE<gt>
 
 =item Copyright (C) 2012 by François-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
 
-=item Copyright (C) 2010, 2011, 2012 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+=item Copyright (C) 2010-2015 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
 
 =item Copyright (C) 2010 by Thomas Chemineau, E<lt>thomas.chemineau@gmail.comE<gt>
 
