@@ -9,7 +9,7 @@ package Lemonldap::NG::Portal::_Choice;
 use Lemonldap::NG::Portal::Simple;
 use Scalar::Util 'weaken';
 
-our $VERSION = '1.9.1';
+our $VERSION = '1.9.3';
 
 ## @cmethod Lemonldap::NG::Portal::_Choice new(Lemonldap::NG::Portal::Simple portal)
 # Constructor
@@ -197,7 +197,8 @@ sub _buildAuthLoop {
         if ( $auth and $userDB and $passwordDB ) {
 
             # Default URL
-            $url ||= "#";
+            $url = ( defined $url ? $url .= $ENV{'REQUEST_URI'} : '#' );
+            $self->lmLog( "Use URL $url", 'debug' );
 
             # Options to store in the loop
             my $optionsLoop =
