@@ -15,7 +15,7 @@ use Unicode::String qw(utf8);
 use strict;
 
 our @EXPORT   = qw(ldap);
-our $VERSION  = '1.9.3';
+our $VERSION  = '1.9.7';
 our $ppLoaded = 0;
 
 BEGIN {
@@ -56,6 +56,8 @@ sub new {
         ( $portal->{ldapTimeout} ? ( timeout => $portal->{ldapTimeout} ) : () ),
         ( $portal->{ldapVersion} ? ( version => $portal->{ldapVersion} ) : () ),
         ( $portal->{ldapRaw}     ? ( raw     => $portal->{ldapRaw} )     : () ),
+        ( $portal->{caFile}      ? ( cafile  => $portal->{caFile} )      : () ),
+        ( $portal->{caPath}      ? ( capath  => $portal->{caPath} )      : () ),
     );
     unless ($self) {
         $portal->lmLog( $@, 'error' );
