@@ -13,19 +13,19 @@ package Lemonldap::NG::Portal::_Multi;
 use Lemonldap::NG::Portal::Simple;
 use Scalar::Util 'weaken';
 
-our $VERSION = '1.4.6';
+our $VERSION = '1.9.1';
 
 ## @cmethod Lemonldap::NG::Portal::_Multi new(Lemonldap::NG::Portal::Simple portal)
 # Constructor
 # @param $portal Lemonldap::NG::Portal::Simple object
 # @return new Lemonldap::NG::Portal::_Multi object
 sub new {
-    my ( $class, $portal ) = splice @_;
+    my ( $class, $portal ) = @_;
     my $self = bless { p => $portal, res => PE_NOSCHEME }, $class;
     weaken $self->{p};
 
     # Browse authentication and userDB configuration
-    my @stack = ( $portal->{authentication}, $portal->{userDB} );
+    my @stack = ( $portal->{multiAuthStack}, $portal->{multiUserDBStack} );
     for ( my $i = 0 ; $i < 2 ; $i++ ) {
         $stack[$i] =~ s/^Multi\s*//;
         foreach my $l ( split /;/, $stack[$i] ) {
@@ -65,7 +65,7 @@ sub new {
 # @param type 0 for authentication, 1 for userDB
 # @return Lemonldap::NG::Portal error code returned by method $sub
 sub try {
-    my ( $self, $sub, $type ) = splice @_;
+    my ( $self, $sub, $type ) = @_;
     my $res;
     my $s   = $self->{stack}->[$type]->[0]->{m} . "::$sub";
     my $old = $self->{stack}->[$type]->[0]->{n};
@@ -83,12 +83,7 @@ sub try {
         # Run subroutine
         $res = $self->{p}->$s();
 
-        # Stop if no error, or if confirmation needed, or if form not filled
-        return $res
-          if ( $res <= 0
-            or $res == PE_CONFIRM
-            or $res == PE_FIRSTACCESS
-            or $res == PE_FORMEMPTY );
+        return $res if $self->stop( $type, $res );
     }
     unless ( $self->next($type) ) {
         return ( $ci ? $res : $self->{res} );
@@ -103,6 +98,34 @@ sub try {
     return $res;
 }
 
+## @method protected boolean stop(int type, int res)
+# Call specific backend to know if multi process should stop
+# @param type 0 for authentication, 1 for userDB
+# @param res return code of last executed sub
+# return true if process should stop
+sub stop {
+    my ( $self, $type, $res ) = @_;
+
+    # Stop if no error, or if confirmation needed, or if form not filled
+    return 1
+      if ( $res <= 0
+        or $res == PE_CONFIRM
+        or $res == PE_FIRSTACCESS
+        or $res == PE_FORMEMPTY );
+
+    # Check specific backend stop method
+    my $stopSub = $self->{stack}->[$type]->[0]->{m} . "::stop";
+
+    my $ret = 0;
+    eval { $ret = $self->{p}->$stopSub($res); };
+    if ($@) {
+        $self->{p}->lmLog( $@, 'debug' );
+        return 0;
+    }
+
+    return $ret;
+}
+
 ## @method protected boolean next(int type)
 # Set the next authentication or userDB module as current. If both
 # authentication and userDB module have the same name, both are changed if
@@ -110,7 +133,7 @@ sub try {
 # @param type 0 for authentication, 1 for userDB
 # return true if an other module is available
 sub next {
-    my ( $self, $type ) = splice @_;
+    my ( $self, $type ) = @_;
 
     if ( $self->{stack}->[$type]->[0]->{n} eq
             $self->{stack}->[ 1 - $type ]->[0]->{n}
@@ -135,13 +158,15 @@ sub next {
 # @param $sub name of the method who has failed
 # @return Lemonldap::NG::Portal error code
 sub replay {
-    my ( $self, $sub ) = splice @_;
+    my ( $self, $sub ) = @_;
     my @subs = ();
     $self->{p}->lmLog( "Replay all methods until sub $sub", 'debug' );
 
     foreach (
         qw(authInit extractFormInfo userDBInit getUser setAuthSessionInfo
-        setSessionInfo setGroups authenticate authFinish)
+        setSessionInfo setMacros setGroups setPersistentSessionInfo
+        setLocalGroups authenticate authFinish)
+
       )
     {
         push @subs, $_;
